@@ -1,3 +1,4 @@
+import os
 from sugarbowl import Function
 from .environment import Environment
 
@@ -44,5 +45,8 @@ class render(Function):
         result = template.render(self.__context)
         if self.__target is None:
             return result
+        dirpath = os.path.dirname(self.__target)
+        if dirpath:
+            os.makedirs(dirpath, exist_ok=True)
         with open(self.__target, 'w') as file:
             file.write(result)
